@@ -3,7 +3,7 @@ package Crypt::SIGMA;
 
 use strict;
 use warnings;
-use bignum;
+#use bignum;
 
 require Exporter;
 
@@ -18,6 +18,8 @@ use Crypt::OpenSSL::ECDSA;
 
 #use Smart::Comments;
 
+our $VERSION=0.012;
+
 our @ISA    = qw(Exporter);
 our @EXPORT = qw/
   derive_z_ke_km
